# Chat object for the ZODB
__doc__ = """ZRTChat item.  Holds information about a particular chat submission"""

__version__ = '0.4'

from Globals import DTMLFile      # fakes a method from a DTML file
from Globals import Persistent    # makes an object stick in the ZODB
from Globals import InitializeClass
#from OFS.CopySupport import CopySource

import OFS.SimpleItem
import Acquisition
import AccessControl.Role
import DateTime
from DocumentTemplate.DT_Var import url_quote
from string import replace
#No GUI constructors here; these are only added programmatically
def manage_addChatItem(self, REQUEST):
    """Add a Chat Item to a ZRTChat."""
    dt = DateTime.DateTime()
    zrtcuser = replace(REQUEST.zrtcuser,';','')
    zrtcuser = url_quote(zrtcuser)
    id = '%s_%s' % (dt.strftime('%m%d%H%M%S'),zrtcuser)
    #Solaris note: strftime string may need to be '%m%d%H%M%s'
    #does anyone know how to check for Solaris?
    try:
        self._setObject(id, ChatItem(id, dt, REQUEST))
    except:
        #OK, it is bad to do an unlimited except, but in this case, likelihood is
        #client is pounding on the submit button like a wild monkey
        pass

#a class for ChatItems on the ZODB
class ChatItem(
    OFS.SimpleItem.Item,   # A simple Principia object. Not Folderish.
    Persistent,            # Make us persistent
    Acquisition.Implicit,  # may need Acquisition in the Future
    AccessControl.Role.RoleManager, # Security manager.
    #CopySource
    ):
    """the chatitem class"""

    meta_type = 'ChatItem' # we do not want this to show up on any add list, but we need meta-type so
                           # that we can get just a list of these things from the folder.

#    icon='misc_/ZRTChat/ChatItem'
#    icon="www/ChatItem.gif"

#    _canCopy=1 #we can be copied

    manage_options = ( # what management options are there?
    {'label': 'Chat Item Info',       'action': 'manage_main'},)

    __ac_permissions__=( # what permissions make sense for us?
    ('View management screens', ('manage_tabs','manage_main', 'manage_edit')),
    ('Change permissions',      ('manage_access',)           ),
    )

    def __init__(self, id, dt, REQUEST):
        """initialise a new instance of ChatItem"""
        self.id = id
        self.dt = dt
        self.zrtcuser=REQUEST.zrtcuser
        self.zrtcmessage=REQUEST.zrtcmessage

    def title(self):
        """return up to 40 chars of the message when asked for title"""
        if len(self.zrtcmessage) > 40:
            return '%s ...' % self.zrtcmessage[:40]
        else:
            return self.zrtcmessage

    def get_size(self):
        """get the size of the text, since the folder we are in wants to display this."""
        return len(self.zrtcmessage)

    manage_main = DTMLFile('www/ChatItemEdit', globals()) # Management Interface

    def manage_edit(self, REQUEST=None):
        """re-edit a zrtchatitem; shouldn't happen much,
        but that's why dt is part of this rather
        than just using its modification date."""
        self.zrtcmessage=REQUEST.zrtcmessage
        if REQUEST is not None:
          return self.manage_main()

InitializeClass(ChatItem)
